# Integration of Tamer with the Unified Planning Library
This is the integrator for [Tamer](https://tamer.fbk.eu/), a temporal planner that supports temporal action-based problems.

## Installation
You can install this engine as an extra requirement of the `unified-planning` package: `pip install unified-planning[tamer]`.
The installation has been tested on the latest versions of ubuntu, windows and macos.

## Default configuration
An heuristic search algorithm described in this [paper](https://ojs.aaai.org//index.php/AAAI/article/view/6553).

## Planning approaches of UP supported
Temporal planning.

## Operative modes of UP currently supported
Oneshot planning, plan validation.

## Acknowledgments
<img src="https://www.aiplan4eu-project.eu/wp-content/uploads/2021/07/euflag.png" width="60" height="40">

This library is being developed for the AIPlan4EU H2020 project (https://aiplan4eu-project.eu) that is funded by the European Commission under grant agreement number 101016442.
